==> fetch.php?media=ocapic-2.3.tar.bz2: ocapic-2.3/src/simulator/lcd/types.ml <==
(*************************************************************************)
(*                                                                       *)
(*                                OCaPIC                                 *)
(*                                                                       *)
(*            Benoit Vaugon, Université Pierre et Marie Curie            *)
(*                                                                       *)
(*    Ce fichier est distribué sous les termes de la licence CeCILL-B    *)
(*    décrite dans le fichier ../../../LICENCE.                          *)
(*                                                                       *)
(*************************************************************************)

type line_mode = One | Two
type display_mode = On | Off
type cursor_mode = Show | Hide | Blink
type bus_mode = Eight | Four
type direction = Left | Right
type font = F5x8 | F5x11

type display = {
  x : int;
  y : int;
  e : Simul.pin;
  rs : Simul.pin;
  rw : Simul.pin;
  bus : Simul.port;
  column_nb : int;
  line_nb : int;
  width : int;
  height : int;
  matrix : bool array array array array;
  cgram : bool array array array;
  ddram : char array;
  mutable cgram_addr : int;
  mutable ddram_addr : int;
  mutable line_mode : line_mode;
  mutable cursor_mode : cursor_mode;
  mutable entry_mode_incr : direction;
  mutable shift_display : bool;
  mutable display_mode : display_mode;
  mutable font : font;
  mutable bus_mode : bus_mode;
}

==> fetch.php?media=ocapic-2.6.tar.bz2: ocapic-2.6/src/simulator/lcd/types.ml <==
(*************************************************************************)
(*                                                                       *)
(*                                OCaPIC                                 *)
(*                                                                       *)
(*            Benoit Vaugon, Université Pierre et Marie Curie            *)
(*                                                                       *)
(*    Ce fichier est distribué sous les termes de la licence CeCILL-B    *)
(*    décrite dans le fichier ../../../LICENCE.                          *)
(*                                                                       *)
(*************************************************************************)

type line_mode = One | Two
type display_mode = On | Off
type cursor_mode = Show | Hide | Blink
type bus_mode = Eight | Four
type direction = Left | Right
type font = F5x8 | F5x11
type ram = DDRam | CGRam

type ddram = char array
type cgram = bool array array array
type matrix = bool array array array array

type display = {
  x : int;
  y : int;
  e : Simul.pin;
  rs : Simul.pin;
  rw : Simul.pin;
  bus : Simul.port;
  column_nb : int;
  line_nb : int;
  width : int;
  height : int;
  matrix : matrix;
  ddram : ddram;
  cgram : cgram;
  mutable ram_addr : int;
  mutable selected_ram : ram;
  mutable line_mode : line_mode;
  mutable cursor_mode : cursor_mode;
  mutable entry_mode_incr : direction;
  mutable shift_display : bool;
  mutable display_mode : display_mode;
  mutable font : font;
  mutable bus_mode : bus_mode;
}
